.. figure:: https://raw.github.com/wq/wq/master/images/128/wq.png
   :align: center
   :target: http://wq.io
   :alt: wq

`wq <http://wq.io>`_ is a modular framework for mobile & desktop
geographic data collection applications.

Getting Started
---------------

::

    pip3 install wq

See `the documentation <http://wq.io/docs>`_ for more information.
See https://github.com/wq/wq to report any issues.

Features
--------

wq is made up of the following submodules, which are maintained as
separate packages.


.. csv-table::
  :header: "Module", "PyPI", "Github", "Description"
  :widths: 100, 100, 100, 500

  |wq_app|, `wq.app <https://pypi.python.org/pypi/wq.app>`_, `wq/wq.app <https://github.com/wq/wq.app>`_, "A JavaScript+Python library for building robust offline-capable HTML5 data entry apps."
  |wq_db|, `wq.db <https://pypi.python.org/pypi/wq.db>`_, `wq/wq.db <https://github.com/wq/wq.db>`_, "A collection of Django database models and REST framework to support design patterns common to data collection systems."
  |wq_io|, `wq.io <https://pypi.python.org/pypi/wq.io>`_, `wq/wq.io <https://github.com/wq/wq.io>`_, "A Python interoperability library for consuming and generating data resources in various formats." 

.. |wq_app| image:: https://raw.github.com/wq/wq/master/images/80/wq.app.png     
  :target: http://wq.io/wq.app
.. |wq_db| image:: https://raw.github.com/wq/wq/master/images/80/wq.db.png     
  :target: http://wq.io/wq.db
.. |wq_io| image:: https://raw.github.com/wq/wq/master/images/80/wq.io.png     
  :target: http://wq.io/wq.io
